DEFAULT_TAG <- "UNK"

### CLASSDEF

setClass("DefaultTagger",
    representation(
      defaultTag = "character", # the tag to attach to each token
      "SequentialBackoffTagger"  # extends the tagger virtual class
    ),
    prototype(defaultTag = DEFAULT_TAG)
)

### GENERICS

setGeneric("defaultTag", function (object) standardGeneric("defaultTag"))

### CONSTRUCTOR

# A constructor for defaultTaggers
DefaultTagger <- function(defaultTag = DEFAULT_TAG) {
  self <- new("DefaultTagger", defaultTag = defaultTag)
  # this is not needed, but interface-preserving
  self <- initSequentialBackoffTagger(self)
  return (self)
}

### VALIDITY

# Checks if this is a valid defaultTagger object
setValidity("DefaultTagger", function(object) {
    if (is.null(object@defaultTag))
      return("DefaultTagger must have character tag")
    return(TRUE)
})

### ACCESSORS

# Access the tag of the given defaultTagger
setMethod("defaultTag", "DefaultTagger", 
  function(object) object@defaultTag)

### MAIN TAGGER IMPL METHS

# Implement the sbt choose.tag method
setMethod("choose.tag", signature(tokens="character", index="integer",
                                  history="character",
                                  tagger="DefaultTagger"),
  function (tokens, index, history, tagger) defaultTag(tagger))


### SHOW

setMethod("show", "DefaultTagger",
  function (object)
    cat(paste("A default tagger with default tag ", defaultTag(object),
              ".\n", sep="")))
