#  A simple functor-style object for encapsulating transform functions

### CLASSDEF

setClass("FunctionalTokenTransform",
  representation("TokenTransform", fun="function", applyToEach="logical"))

### GENERICS

setGeneric("FunctionalTokenTransform",
  function (fun, applyToEach) standardGeneric("FunctionalTokenTransform"))

### CONSTRUCTION

setMethod("FunctionalTokenTransform",
          signature(fun="function", applyToEach="logical"),
  function (fun, applyToEach)
    new("FunctionalTokenTransform", fun=fun, applyToEach=applyToEach))

setMethod("FunctionalTokenTransform",
          signature(fun="function", applyToEach="missing"),
  function (fun, applyToEach)
    new("FunctionalTokenTransform", fun=fun, applyToEach=FALSE))

### ACCESSORS

setMethod("func", "FunctionalTokenTransform",
  function (object) object@fun)

setMethod("isAppliedToEach", "FunctionalTokenTransform",
  function (object) object@applyToEach)

### TRANSFORM overriding

setMethod("transformTokens", signature(object="character",
                                       transform="FunctionalTokenTransform",
                                       tokenizer="missing",
                                       index="missing"),
  function (object, transform, tokenizer, index) {
    if (is(object, "TextDocument"))
      object <- tokenize(object)

     fun <- func(transform)

     if (isAppliedToEach(transform))
      sapply(object, fun, USE.NAMES=FALSE)
     else
      fun(object)
   })

### SHOW

setMethod("show", "FunctionalTokenTransform",
  function (object)
    if (isAppliedToEach(object))
      cat("A functional token transform applying to each token the function:\n",
          format(func(object)), "\n")
    else
      cat("A functional token transform using function:\n",
          format(func(object)), "\n"))
