# MatchObjects are simple wrappers around the python equivalent
setClass("MatchObject", representation(pointer="externalptr"))

### GENERICS

setGeneric("re.expand",
  function (match, template) standardGeneric("re.expand"))

setGeneric("re.group",
  function (match, group1=0, ...) standardGeneric("re.group"))

setGeneric("re.groups",
  function (match, default=NA) standardGeneric("re.groups"))

setGeneric("re.groupdict", 
  function (match, default=NA) standardGeneric("re.groupdict"))

setGeneric("re.start", function (match, group=0) standardGeneric("re.start"))

setGeneric("re.end", function (match, group=0) standardGeneric("re.end"))

setGeneric("re.span", function (match, group=0) standardGeneric("re.span"))

setGeneric("re.pos", function (match) standardGeneric("re.pos"))

setGeneric("re.endpos", function (match) standardGeneric("re.endpos"))

setGeneric("re.lastindex", function (match) standardGeneric("re.lastindex"))

setGeneric("re.lastgroup", function (match) standardGeneric("re.lastgroup"))

setGeneric("re.re", function (match) standardGeneric("re.re"))

setGeneric("re.string", function (match) standardGeneric("re.string"))

# To get rid of warnings
setMethod("is.na", "MatchObject", function (x) FALSE)

# Field Accessors
#
# Everything returns an int or string (or NULL if the underlying
# python attribute is set to None).  See
# http://docs.python.org/lib/match-objects.html for details.  The one
# exception is re.re which returns the RegexObject that generated this
# MatchObject (note that techinically this is an external pointer to a
# python reference (everything is a reference in python, remember) to
# the regex object that created this object.  This will behave like a
# reference basically---although RegexObjects are unmutable so this is
# not really important).

setMethod("re.expand", signature(match="MatchObject",template="character"),
  function (match, template)
    return(.Call("expand_MatchObject", match@pointer, template)))

fixGroups <- function(groups)
{
  result <- vector("list", length(groups))
  for (i in 1:length(groups)) {
    if ((length(groups[[i]]) < 1) || 
        ((! is.numeric(groups[[i]])) && (!  is.character(groups[[i]]))))
      stop("Arguments to re.group must be single integers or characters")
    else if (is.numeric(groups[[i]]))
      result[i] <- as.integer(groups[[i]])
    else
      result[i] <- groups[[i]]
  }
  return (result)
}

setMethod("re.group", signature(match="MatchObject"),
  function(match, group1=0, ...) {
    groups <- fixGroups(list(group1, ...))
    return(.Call("group_MatchObject", match@pointer, groups))
  }
)

setMethod("re.groups", signature(match="MatchObject"),
  function (match, default=NA)
    return(.Call("groups_MatchObject", match@pointer, default)))

setMethod("re.start", signature(match="MatchObject"),
  function (match, group=0)
    if (! is.numeric(group) || group < 0)
      stop("group must be integer >= 0")
    else
      return(.Call("start_MatchObject", match@pointer, as.integer(group))))

setMethod("re.end", signature(match="MatchObject"),
  function (match, group=0)
    if (! is.numeric(group) || group < 0)
      stop("group must be integer >= 0")
    else
      return(.Call("end_MatchObject", match@pointer, as.integer(group))))

setMethod("re.span", signature(match="MatchObject"),
  function (match, group=0)
    c(re.start(match, group), re.end(match, group)))

#
#setMethod("re.group", signature(match="MatchObject"),
#  function (match, group1=0, ...) {
#  }
#)


setMethod("re.pos", signature(match="MatchObject"),
  function (match) return(.Call("pos_MatchObject", match@pointer)))

setMethod("re.endpos", signature(match="MatchObject"),
  function (match) return(.Call("endpos_MatchObject", match@pointer)))

setMethod("re.lastindex", signature(match="MatchObject"),
  function (match) return(.Call("lastindex_MatchObject", match@pointer)))

setMethod("re.lastgroup", signature(match="MatchObject"),
  function (match) return(.Call("lastgroup_MatchObject", match@pointer)))

setMethod("re.re", signature(match="MatchObject"),
  function (match) {
    ptr <- .Call("re_MatchObject", match@pointer)
    return(new("RegexObject", pointer = ptr))
  }
)

setMethod("re.string", signature(match="MatchObject"),
  function (match) return(.Call("string_MatchObject", match@pointer)))

setMethod("show", "MatchObject",
  function (object) {
    cat("MatchObject\n")
  }
)

# List versions of methods
setMethod("re.expand", signature(match="list"),
  function (match, template)
    lapply(match, 
      function (x, template) 
        if (is.na(x)) return (NA) 
        else return(re.expand(x, template)), template))

setMethod("re.group", signature(match="list"),
  function(match, group1 = 0, ...)
    lapply(match,
      function(x, group1, ...)
        if (is.na(x)) return (NA)
        else return(re.group(x, group1, ...)), group1, ...))

setMethod("re.groups", signature(match="list"),
  function (match, default=NA)
    lapply(match, 
      function (x, default)
        if (is.na(x)) return (NA)
        else return(re.groups(x, default)), default))


setMethod("re.start", signature(match="list"),
  function (match, group=0)
    lapply(match, 
      function (x, group)
        if (is.na(x)) return (NA)
        else return(re.start(x, group)), group))

setMethod("re.end", signature(match="list"),
  function (match, group=0)
    lapply(match, 
      function (x, group)
        if (is.na(x)) return (NA)
        else return(re.end(x, group)), group))

setMethod("re.span", signature(match="list"),
  function (match, group=0)
    lapply(match, 
      function (x, group)
        if (is.na(x)) return (NA)
        else return(re.span(x, group)), group))

# Tried to put these in a loop but trickier than you'd think
setMethod("re.pos", "list",
  function(match)
    lapply(match,
      function(x) if (is.na(x)) return (NA) else return(re.pos(x))))

setMethod("re.endpos", "list",
  function(match)
    lapply(match,
      function(x) if (is.na(x)) return (NA) else return(re.endpos(x))))

setMethod("re.lastindex", "list",
  function(match)
    lapply(match,
      function(x) if (is.na(x)) return (NA) else return(re.lastindex(x))))

setMethod("re.lastgroup", "list",
  function(match)
    lapply(match,
      function(x) if (is.na(x)) return (NA) else return(re.lastgroup(x))))

setMethod("re.re", "list",
  function(match)
    lapply(match,
      function(x) if (is.na(x)) return (NA) else return(re.re(x))))

setMethod("re.string", "list",
  function(match)
    lapply(match,
      function(x) if (is.na(x)) return (NA) else return(re.string(x))))

