# A simple regular expression token transform

### CLASSDEF

setClass("RegexTokenTransform",
  representation("FunctionalTokenTransform", pattern="RegexObject",
                 repl="character", count = "integer"))

### GENERICS

setGeneric("RegexTokenTransform",
  function (pattern, repl="", count=0)
    standardGeneric("RegexTokenTransform"))

setGeneric("replacementString",
  function (object) standardGeneric("replacementString"))

setGeneric("replacementCount",
  function (object) standardGeneric("replacementCount"))

### CONSTRUCTOR

setMethod("RegexTokenTransform", signature("RegexObject", "character"),
  function (pattern, repl="", count=0) {
    if (length(repl) != 1)
      stop("Replacement string vector should be of length 1.")
    if (length(count) != 1 || (! is.numeric(count)) || count < 0)
      stop(paste("Bad count: ", count))
    fun <- function (x) unlist(re.sub(pattern, repl, x, count)) 
    new("RegexTokenTransform", FunctionalTokenTransform(fun, FALSE),
                               pattern=pattern, repl=repl,
                               count=as.integer(count))
  })

setMethod("RegexTokenTransform", signature("character", "character"),
  function (pattern, repl="", count=0)
    RegexTokenTransform(re.compile(pattern), repl, count))

# XXX No default for now

### ACCESSORS

setMethod("pattern", "RegexTokenTransform",
  function (object) object@pattern)

setMethod("replacementString", "RegexTokenTransform",
  function (object) object@repl)

setMethod("replacementCount", "RegexTokenTransform",
  function (object) object@count)

### SHOW

setMethod("show", "RegexTokenTransform",
  function (object)
    cat("A regular expression token transform with replacement string ",
        replacementString(object), ", replacement count ", 
        replacementCount(object), ", and using pattern:\n",
        re.pattern(pattern(object)), "\n"))
