# A base class for all tagged views.  Provides a slot for the tagger
# used and defines the tagger accessor method.

### BIZARRE PLACEMENT / FORWARD REFERENCE

# This is like a C++ forward reference...kinda.  See TokenizedView.R
# for the details/
setClass("Tagger", representation("VIRTUAL"))

### CLASS DEF

# TaggedViews are TokenizedViews with a tagger.
setClass("TaggedView", 
  representation(tagger = "Tagger", "VIRTUAL"))

### GENERICS

setGeneric("tagger", function (object) standardGeneric("tagger"))

### ACCESSORS

setMethod("tagger", "TaggedView",
  function (object) return (object@tagger))


## This code is the same for TaggedCVs and TaggedDVs so they inherit
# it from here.

# Specialization for TaggedToken value
setMethod("has", signature(object="TaggedView",
                           value="TaggedToken"),
  function (object, value, ...) has(object, as.character(value), ...))

# Specialization for TaggedToken value
setMethod("freq", signature(object="TaggedView",
                            value="TaggedToken"),
  function (object, value, ...)
    if (has(object, value, what="TaggedToken"))
      return (freqTable(object, what="TaggedTokens")[[as.character(value)]])
    else
      return (0))
