\name{FunctionalTokenTransform}
\alias{FunctionalTokenTransform}

\title{FunctionalTokenTransform}

\description{
Constructs a \code{\linkS4class{FunctionalTokenTransform}} object.
}

\usage{
FunctionalTokenTransform(fun, applyToEach=FALSE)
}

\value{
  An S4 object of class \code{\linkS4class{FunctionalTokenTransform}}.
}

\arguments{
\item{fun}{A function defining a transformation algorithm.}
\item{applyToEach}{A \code{logical} indicating whether the transform
function expects a vector of tokens or a single token.}
}

\details{
  A \code{FunctionalTokenTransform} object encapsulates a simple function
  and uses it to transform a sequence of tokens.  The function should
  take a single \code{character} vector (one token per element) as its
  argument and return a \code{character} vector of post-transform tokens.
  If \code{isAppliedToEach} is set to true, the function should expect
  only a single token and return a length 1 \code{character} vector.
}

\examples{
# A tokenized view of crude in terms of bigrams
data(crude)
pcrude <- PCorpus(crude)
bigTrans <- FunctionalTokenTransform(
  function (x) {
    index <- lapply(1:length(x), function (x) seq(x, x+1))
    sapply(index, function (y) paste(x[y], collapse=" "))
  })

crude.bigram <- transformTokens(pcrude, bigTrans)
}

\author{Tony Fader, Gary King, Dan Pemstein, and Kevin Quinn}

\seealso{
  \code{\linkS4class{FunctionalTokenTransform}}
}

\keyword{methods}
