\name{RegexObject-class}
\docType{class}
\alias{RegexObject-class}
\alias{RegexObject-methods}
\alias{RegexObject}
\alias{re.findall}
\alias{re.flags}
\alias{re.match}
\alias{re.pattern}
\alias{re.search}
\alias{re.split}
\alias{re.subn}
\alias{re.sub}
\alias{show,RegexObject-method}

\title{Class "RegexObject"}

\description{A RegexObject represent a compiled regular expression.
These objects wrap objects from the Python re module and perform
computation in Python under the hood.  See
http://www.python.org/doc/lib/module-re.html for details.}

\section{Objects from the Class}{
Objects can be created by calls of the form 
\code{re.compile(pattern, ignorecase=FALSE, locale=FALSE,
multiline=FALSE, dotall=FALSE, unicode=FALSE, verbose=FALSE)} where
pattern is a string containing a regular expression.  The other
parameters set various flags; see
http://www.python.org/doc/lib/node46.html for details.
}

\section{Methods}{
  \describe{
    \item{re.match}{\code{signature(pattern = "RegexObject", string = "character")}: Returns a \code{\linkS4class{MatchObject}} if \code{pattern} matches zero or more characters at the beginning of \code{string}.  Otherwise, return \code{NA}.  Takes two optional arguments, \code{pos} and \code{endpos}, specifying offsets into \code{string} at which to begin and end the search.}
    \item{re.search}{\code{signature(pattern = "RegexObject", string = "character")}: Returns a \code{\linkS4class{MatchObject}} representing the first match of \code{pattern} found in \code{string}.  Returns \code{NA} if no match is found.  Takes two optional arguments, \code{pos} and \code{endpos}, specifying offsets into \code{string} at which to begin and end the search.}
    \item{re.findall}{\code{signature(pattern = "RegexObject", string = "character")}: Returns a list of all non-overlapping matches of \code{pattern} in the given \code{string}.   Takes two optional arguments, \code{pos} and \code{endpos}, specifying offsets into \code{string} at which to begin and end the search.  The returned object is a generic list containing one character vector per match.  If \code{pattern} contains grouping parentheses each vector may contain multiple match strings.}
    \item{re.split}{\code{signature(pattern = "RegexObject", string = "character")}: Splits \code{string} by \code{pattern}, returning a \code{character} vector.  Will include matched separators in the returned vector if capturing parentheses are used in \code{pattern}.  Takes an optional argument, \code{maxsplit}, which specifies the maximum number of splits to make (the remainder of the string is returned as the last element of the result vector).}
    \item{re.sub}{\code{signature(pattern = "RegexObject", repl = "character", string = "character")}: Returns the string obtained by replacing the leftmost non-overlapping occurences of \code{pattern} in \code{string} by \code{repl}.  \code{string} is returned if the pattern is not found.  The method processes backslashed escapes in \code{repl} and replaces backreferences with their respective matches.  The optional argument \code{count} sets the maximum number of pattern matches to replace.}
    \item{re.subn}{\code{signature(pattern = "RegexObject", repl = "character", string = "character")}: This method is just like \code{sub} except that it returns a list containing both the modified \code{string} object and an integer indicating the number of replacements made.}
    \item{re.pattern}{\code{signature(pattern = "RegexObject")}: Returns a string containing the regular expression represented by \code{pattern}.}
    \item{re.flags}{\code{signature(pattern = "RegexObject")}: Returns a list of flags that are set for \code{pattern}.}
  }
}

\references{Python Library Reference: re -- Regular expression
operations. http://www.python.org/doc/lib/module-re.html.}

\author{Dan Pemstein <dpemstein@iq.harvard.edu>}

\seealso{
  \code{\linkS4class{MatchObject}}
}

\examples{
# Some strings to match.  Note that we can apply RegexObject methods
# directly to the string vector and they will return vectors/lists of
# results.
str <- c("123", "??", "123xxx", "12?af?123fd", "!!!", "Hello, how are you?")

# Matching - notice the double-escaping
p1 <- re.compile('(\\\d+)|([a-z]+)+', ignorecase=TRUE)
m1 <- re.match(p1, str)

# Searching - again, notice the double-escaping
p2 <- re.compile('([\\\?\\\!]+)|(h[a-z]+)')
m2 <- re.search(p2, str)

# Splitting
p3 <- re.compile('\\\W+')
splut1 <- re.split(p3, str)
p4 <- re.compile('(\\\W+)')   # now with capturing
splut2 <- re.split(p4, str)

# Finding all matches.  Note the second example uses groups
p5 <- re.compile("\\\w+")
p6 <- re.compile("((\\\w)(\\\w+))")
f1 <- re.findall(p5, str)
f2 <- re.findall(p6, str)

# Replacing substrings
s1 <- re.sub(p1, "BLOB", str)
s2 <- re.sub(p1, "BLOB", str, 1)
s3 <- re.sub(p2, "BLOB", str)
s4 <- re.subn(p2, "BLOB", str, 2)
s5 <- re.subn(p4, "[\\\g<1>]", str)    # using named backreferences
s6 <- re.subn(p4, "[\\\1]", str, 2)    # using numeric backreferences
}

\keyword{classes}
