\name{SequentialBackoffTagger-class}
\docType{class}
\alias{SequentialBackoffTagger-class}
\alias{backoff,SequentialBackoffTagger-method}
\alias{choose.tag,character,integer,character,SequentialBackoffTagger-method}
\alias{tag.one,character,integer,character,SequentialBackoffTagger-method}
\alias{tag,character,SequentialBackoffTagger,missing,missing-method}

\title{Class "SequentialBackoffTagger"}

\description{
  An abstract class for taggers that tag tokens sequentially, left to
  right, and fall back to an optional backoff tagger for tokens they
  can't tag.
}

\section{Objects from the Class}{A virtual Class: No objects may be created from it.}

\section{Extends}{
Class \code{"\linkS4class{Tagger}"}, directly.
}

\section{Methods}{
  \describe{
    \item{backoff}{\code{signature(object = "SequentialBackoffTagger")}:
      Returns the object's backoff tagger, or \code{NULL} if none exists.}

    \item{choose.tag}{\code{signature(tokens = "character",
                                      index = "integer",
                                      history = "character",
                                      tagger = "SequentialBackoffTagger")}:
      Take a vector of tokens, an offset into that vector indicating
      the token to tag, and a vector of tags applied to the tokens
      preceding the current token, and apply the given tagger to
      generate a tag for the current token.  This method must be
      overridden by all extending classes.   Overriding methods
      should return a single \code{character} tag, or \code{NULL} if
      no tag is found.  Overriding methods should NOT fall back to the
      backoff tagger if no tag is found!}

    \item{tag.one}{\code{signature(tokens = "character", index = "integer",
                                   history = "character",
                                   tagger = "SequentialBackoffTagger")}:
      Take a vector of tokens, an offset into that vector indicating
      the token to tag, and a vector of tags applied to the tokens
      preceding the current token, and apply the given tagger to
      generate a tag for the current token, invoking the backoff
      tagger if no tag is found.}

    \item{tag}{\code{signature(object = "character",
                               tagger = "SequentialBackoffTagger")}:
      Apply the \code{SequentialBackoffTagger} to a \code{character}
      object containing a sequence of tokens, returning a
      \code{character} vector of tags.  Note that this method will
      apply the default tokenizer to generate a token vector if
      \code{object} happens to be a \code{\linkS4class{TextDocument}}
      object. }
	 }
}

\author{Tony Fader, Gary King, Dan Pemstein, and Kevin Quinn}

\seealso{
  \code{\link{tag}}
  \code{\link{choose.tag}}
  \code{\link{tag.one}}
  \code{\linkS4class{Tagger}}
  \code{\linkS4class{DefaultTagger}}
  \code{\linkS4class{RegexTagger}}
  \code{\linkS4class{NgramTagger}}
  \code{\linkS4class{AffixTagger}}
}

\keyword{classes}
