\name{TaggedDocumentView-class}
\docType{class}
\alias{TaggedDocumentView-class}
\alias{TaggedDocumentView}
\alias{[,TaggedDocumentView,ANY,ANY,ANY-method}
\alias{freq,TaggedDocumentView,character-method}
\alias{freqTable,TaggedDocumentView-method}
\alias{has,TaggedDocumentView,character-method}
\alias{taggedTokens,TaggedDocumentView-method}
\alias{tags,TaggedDocumentView-method}
\alias{unique,TaggedDocumentView-method}

\title{Class "TaggedDocumentView"}

\description{
  A view of a \code{\linkS4class{TextDocument}} object (contained
  within a \code{\linkS4class{PCorpus}}) as a sequence of token
  labels, or tags.
}

\section{Objects from the Class}{
    In general, \code{TaggedDocumentView} objects should not be
    constructed directly unless you are writing code to extend this
    package. Instead, they can be obtained from an existing 
    \code{\linkS4class{PCorpus}} object by calling
    \code{tag(corpus, index=i)}.
}

\section{Extends}{
Class \code{"\linkS4class{TaggedView}"}, directly.
Class \code{"\linkS4class{TokenizedDocumentView}"}, directly.
Class \code{"\linkS4class{DocumentView}"}, by class
"TokenizedDocumentView", distance 2.
Class \code{"\linkS4class{TokenizedView}"}, by class
"TokenizedDocumentView", distance 2.
Class \code{"\linkS4class{View}"}, by class "TokenizedDocumentView",
distance 3.
}

\section{Methods}{
  \describe{
    \item{[}{\code{signature(x = "TaggedDocumentView", i = "ANY", j = "ANY",
                             drop = "ANY")}:
      Returns specific \code{\linkS4class{TaggedToken}}s, tags,
      tokens, or slices of any of the above.  Tokens and their tags
      are indexed in the order they appear by \code{i}, setting
      \code{j = 1} requests tokens, \code{j = 2} requests tags, and
      leaving \code{j} missing requests tagged tokens.}

    \item{freq}{\code{signature(object = "TaggedDocumentView",
                                value = "character")}:
      Returns the frequency of the token-tag pair \code{value} within the
      \code{TaggedDocumentView}.  The pair should be written in the
      form "token/tag".  The optional \code{what
      = c("TaggedTokens", "Tokens", "Tags")} indicates where the
      method should search for \code{value}.}

    \item{freqTable}{\code{signature(object = "TaggedDocumentView")}:
      Returns a table of the frequenices of token-tag pairs within the
      \code{TaggedDocumentView}.  The optional
      \code{what = c("TaggedTokens", "Tokens", "Tags")} indicates
      what type of frequency table the method should return.}

    \item{has}{\code{signature(object = "TaggedDocumentView",
                               value = "character")}:
      Returns \code{TRUE} if the token-tag pair \code{value} is
      contained within the \code{TaggedDocumentView}. The optional
      \code{what = c("TaggedTokens", "Tokens", "Tags")} indicates
      where the method should search for \code{value}.}

    \item{taggedTokens}{\code{signature(object = "TaggedDocumentView")}:
      Returns a \code{\linkS4class{TaggedToken}} object containing the
      tagged tokens represented by the view.}

    \item{tags}{\code{signature(object = "TaggedDocumentView")}:
      Returns a character vector of the \code{TaggedDocumentView}'s
      tags. }

    \item{unique}{\code{signature(x = "TaggedDocumentView")}:
      Returns a character vector of the \code{TaggedDocumentView}'s
      unique token-tag pairs.  The optional \code{what =
      c("TaggedTokens", "Tokens", "Tags")} indicates what set of
      unique values to return.}
	 }
}

\author{Tony Fader, Gary King, Dan Pemstein, and Kevin Quinn}

\seealso{
  \code{\link{tag}}
  \code{\linkS4class{DocumentView}}
  \code{\linkS4class{TaggedView}}
  \code{\linkS4class{TaggedCorpusView}}
  \code{\linkS4class{TaggedToken}}
  \code{\linkS4class{TokenizedView}}
  \code{\linkS4class{TokenizedCorpusView}}
  \code{\linkS4class{TokenizedDocumentView}}
  \code{\linkS4class{PCorpus}}
}

\keyword{classes}
