#include <Python.h>
#include <Rinternals.h>
#include <Rdefines.h>
#include "embed_nltk.h"
#include "sequential_backoff_tagger.h"

/* Constructs an n-gram tagger from a training list and returns the
 * address of the tagger object.  Takes (as an integer) n, (also as an
 * integer) a cutoff, and a sequence of sentences as an R nested list,
 * where each sublist is a sentence, and each sub-sublist is a
 * token-tag pair.
 *
 * Called directly from R using the .Call interface.
 */
inline SEXP 
construct_ngram_tagger (SEXP r_n, SEXP raw_train_list, SEXP r_cutoff)
{ 
  /* Declarations */
  SEXP ptr; PyObject *train_list, *argtuple, *backoff;
  
  /* Transform the passed in data to the correct format. */
  train_list = r2p_tagged_token_sentences(raw_train_list);

  //PyObject_Print(train_list, stdout, 0);

  /* Stick the training data and other args in a tuple to pass */
  argtuple = PyTuple_New(5);
  PyTuple_SetItem(argtuple, 0, PyInt_FromLong((long)INTEGER(r_n)[0]));
  PyTuple_SetItem(argtuple, 1, train_list); /* steals train_list ref */
  PyTuple_SetItem(argtuple, 2, Py_None);    /* model param */
  PyTuple_SetItem(argtuple, 3, Py_None);    /* backoff param */
  PyTuple_SetItem(argtuple, 4, PyInt_FromLong((long)INTEGER(r_cutoff)[0]));

  /* Create the tagger and get an R external pointer to it. */
  ptr = construct_wrapped_python_object(nltk_tag_pnt(), argtuple, 
      "NgramTagger", destruct_python_object);
  
  UNPROTECT(1); // unprotect the ptr object
  return ptr;
}
