#include <Python.h>
#include <Rinternals.h>
#include <Rdefines.h>
#include "embed_nltk.h"
#include "sequential_backoff_tagger.h"

/* Constructs a regexp tagger from a regex list and returns the
 * address of the tagger object.  Takes a sequence of token-tag pairs
 * as an R list of lists where each sublist is a pair containing a
 * token and a tag.
 *
 * Called directly from R using the .Call interface.
 */
inline SEXP 
construct_regexp_tagger (SEXP r_regexp_list)
{ 
  /* Declarations */
  SEXP ptr, internal;
  PyObject *regexp_list, *argtuple, *constructor, *tagger, *backoff;
  
  /* Transform the passed in data to the correct format, slightly
   * abusing the r2p_tagged_token_list function. */
  regexp_list = r2p_tagged_token_list(r_regexp_list);

  /* Debug code: PyObject_Print(regexp_list, stdout, 0); */

  argtuple = PyTuple_New(1);
  PyTuple_SetItem(argtuple, 0, regexp_list); /* steals ref */

  /* Create the tagger and get an R external pointer to it. */
  ptr = construct_wrapped_python_object(nltk_tag_pnt(), argtuple, 
      "RegexpTagger", destruct_python_object);

  UNPROTECT(1);
  return ptr;
}
