#ifndef __SEQUENTIAL_BACKOFF_TAGGER_H__
#define __SEQUENTIAL_BACKOFF_TAGGER_H__

/* 
 *
 */

#include <Python.h>
#include <Rinternals.h>
#include <Rdefines.h>
#include "embed_nltk.h"
#include "tagger.h"

/*
 * Called directly from R with the .Call interface.
 */
inline SEXP
p_choose_tag (SEXP ptr, SEXP r_tokens, SEXP r_index, SEXP r_hist)
{
  PyObject *tokens, *index, *hist, *tagger, *tag;
  SEXP r_tag;

  /* Convert R types to python equivs */
  tokens = r2p_token_list(r_tokens);
  index = r2p_int(r_index);
  hist = r2p_token_list(r_hist);

  /* Get the tagger object from the external pointer */
  tagger = get_tagger(ptr);

  /* Call the tagger's choose_tag method */
  tag = 
    call_python_method_va(tagger, "choose_tag", 3, tokens, index, hist);

  if (tag == Py_None) {
    Py_DECREF(tag);
    return R_NilValue;
  }

  /* Convert back to R */
  r_tag = p2r_string(tag);
  Py_DECREF(tag);

  /* Unprotect r_tag and return*/
  UNPROTECT(1);
  return r_tag;
}

#endif /* __SEQUENTIAL_BACKOFF_TAGGER_H__ */
